"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.WebPresentationModeManager = void 0;
var _reactNativeTheoplayer = require("react-native-theoplayer");
var _PlayerEvents = require("../event/PlayerEvents");
var _FullscreenAPI = require("./FullscreenAPI");
var _CommonUtils = require("../../utils/CommonUtils");
class WebPresentationModeManager {
  _presentationMode = _reactNativeTheoplayer.PresentationMode.inline;
  _element = undefined;
  constructor(player, eventForwarder) {
    this._player = player;
    this._eventForwarder = eventForwarder;
    this._player.presentation.addEventListener('presentationmodechange', this.updatePresentationMode);
  }
  get presentationMode() {
    return this._presentationMode;
  }
  set presentationMode(presentationMode) {
    if (presentationMode === this._presentationMode) {
      return;
    }
    this.prepareForPresentationModeChanges();
    if (_FullscreenAPI.fullscreenAPI !== undefined) {
      // All other browsers
      if (presentationMode === _reactNativeTheoplayer.PresentationMode.fullscreen) {
        const appElement = document.getElementById('app') ?? document.getElementById('root');
        if (appElement !== null) {
          const promise = appElement[_FullscreenAPI.fullscreenAPI.requestFullscreen_]();
          if (promise && promise.then) {
            promise.then(_CommonUtils.noOp, _CommonUtils.noOp);
          }
        }
      } else if (presentationMode === _reactNativeTheoplayer.PresentationMode.pip) {
        this._player.presentation.requestMode('native-picture-in-picture');
      } else {
        if (this._presentationMode === _reactNativeTheoplayer.PresentationMode.fullscreen) {
          const promise = document[_FullscreenAPI.fullscreenAPI.exitFullscreen_]();
          if (promise && promise.then) {
            promise.then(_CommonUtils.noOp, _CommonUtils.noOp);
          }
        }
        if (this._presentationMode === _reactNativeTheoplayer.PresentationMode.pip) {
          void document.exitPictureInPicture();
        }
      }
    } else {
      // iOS Safari doesn't properly support fullscreen, use native fullscreen instead
      if (presentationMode === _reactNativeTheoplayer.PresentationMode.fullscreen) {
        this._element?.webkitEnterFullscreen?.();
      } else if (presentationMode === _reactNativeTheoplayer.PresentationMode.pip) {
        this._player.presentation.requestMode('native-picture-in-picture');
      } else {
        this._element?.webkitSetPresentationMode?.(_reactNativeTheoplayer.PresentationMode.inline);
      }
    }
  }
  prepareForPresentationModeChanges() {
    const elements = this._player.element.children;
    for (const element of Array.from(elements)) {
      if (element.tagName === 'VIDEO') {
        const videoElement = element;
        if (videoElement.src !== null && videoElement.src !== '' || videoElement.srcObject !== null) {
          this._element = videoElement;
          break;
        }
      }
    }
    // listen for fullscreen updates on document
    if (_FullscreenAPI.fullscreenAPI !== undefined) {
      document.addEventListener(_FullscreenAPI.fullscreenAPI.fullscreenchange_, this.updatePresentationMode);
      document.addEventListener(_FullscreenAPI.fullscreenAPI.fullscreenerror_, this.updatePresentationMode);
    }
  }
  updatePresentationMode = () => {
    // detect new presentation mode
    let newPresentationMode = _reactNativeTheoplayer.PresentationMode.inline;
    if (_FullscreenAPI.fullscreenAPI !== undefined && document[_FullscreenAPI.fullscreenAPI.fullscreenElement_] !== null) {
      newPresentationMode = _reactNativeTheoplayer.PresentationMode.fullscreen;
    } else if (this._player.presentation.currentMode === 'native-picture-in-picture') {
      newPresentationMode = _reactNativeTheoplayer.PresentationMode.pip;
    }

    // when changed, notify by dispatching presentationModeChange event
    const previousPresentationMode = this._presentationMode;
    if (newPresentationMode !== previousPresentationMode) {
      this._presentationMode = newPresentationMode;
      this._eventForwarder.dispatchEvent(new _PlayerEvents.DefaultPresentationModeChangeEvent(this._presentationMode, previousPresentationMode));
    }
  };
}
exports.WebPresentationModeManager = WebPresentationModeManager;
//# sourceMappingURL=WebPresentationModeManager.js.map